==> distribution-6.19.3.zip: drr/regulation/cftc/rewrite/trade/validation/datarule/CFTCPart43TransactionReportUniqueTransactionIdentifierCondition.java <==
package drr.regulation.cftc.rewrite.trade.validation.datarule;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.annotations.RosettaDataRule;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.cftc.rewrite.trade.CFTCPart43TransactionReport;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

/**
 * @version 6.19.3
 */
@RosettaDataRule("CFTCPart43TransactionReportUniqueTransactionIdentifierCondition")
@ImplementedBy(CFTCPart43TransactionReportUniqueTransactionIdentifierCondition.Default.class)
public interface CFTCPart43TransactionReportUniqueTransactionIdentifierCondition extends Validator<CFTCPart43TransactionReport> {
	
	String NAME = "CFTCPart43TransactionReportUniqueTransactionIdentifierCondition";
	String DEFINITION = "if uniqueSwapIdentifier is absent then uniqueTransactionIdentifier exists else uniqueTransactionIdentifier is absent";
	
	class Default implements CFTCPart43TransactionReportUniqueTransactionIdentifierCondition {
	
		@Override
		public List<ValidationResult<?>> getValidationResults(RosettaPath path, CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			ComparisonResult result = executeDataRule(cFTCPart43TransactionReport);
			if (result.get()) {
				return Arrays.asList(ValidationResult.success(NAME, ValidationResult.ValidationType.DATA_RULE, "CFTCPart43TransactionReport", path, DEFINITION));
			}
			
			String failureMessage = result.getError();
			if (failureMessage == null || failureMessage.contains("Null") || failureMessage == "") {
				failureMessage = "Condition has failed.";
			}
			return Arrays.asList(ValidationResult.failure(NAME, ValidationResult.ValidationType.DATA_RULE, "CFTCPart43TransactionReport", path, DEFINITION, failureMessage));
		}
		
		private ComparisonResult executeDataRule(CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			try {
				if (notExists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueSwapIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueSwapIdentifier())).getOrDefault(false)) {
					return exists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueTransactionIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueTransactionIdentifier()));
				}
				return notExists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueTransactionIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueTransactionIdentifier()));
			}
			catch (Exception ex) {
				return ComparisonResult.failure(ex.getMessage());
			}
		}
	}
	
	@SuppressWarnings("unused")
	class NoOp implements CFTCPart43TransactionReportUniqueTransactionIdentifierCondition {
	
		@Override
		public List<ValidationResult<?>> getValidationResults(RosettaPath path, CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			return Collections.emptyList();
		}
	}
}

==> distribution-6.21.2.zip: drr/regulation/cftc/rewrite/trade/validation/datarule/CFTCPart43TransactionReportUniqueTransactionIdentifierCondition.java <==
package drr.regulation.cftc.rewrite.trade.validation.datarule;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.annotations.RosettaDataRule;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.cftc.rewrite.trade.CFTCPart43TransactionReport;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

/**
 * @version 6.21.2
 */
@RosettaDataRule("CFTCPart43TransactionReportUniqueTransactionIdentifierCondition")
@ImplementedBy(CFTCPart43TransactionReportUniqueTransactionIdentifierCondition.Default.class)
public interface CFTCPart43TransactionReportUniqueTransactionIdentifierCondition extends Validator<CFTCPart43TransactionReport> {
	
	String NAME = "CFTCPart43TransactionReportUniqueTransactionIdentifierCondition";
	String DEFINITION = "if uniqueSwapIdentifier is absent then uniqueTransactionIdentifier exists else uniqueTransactionIdentifier is absent";
	
	class Default implements CFTCPart43TransactionReportUniqueTransactionIdentifierCondition {
	
		@Override
		public List<ValidationResult<?>> getValidationResults(RosettaPath path, CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			ComparisonResult result = executeDataRule(cFTCPart43TransactionReport);
			if (result.getOrDefault(true)) {
				return Arrays.asList(ValidationResult.success(NAME, ValidationResult.ValidationType.DATA_RULE, "CFTCPart43TransactionReport", path, DEFINITION));
			}
			
			String failureMessage = result.getError();
			if (failureMessage == null || failureMessage.contains("Null") || failureMessage == "") {
				failureMessage = "Condition has failed.";
			}
			return Arrays.asList(ValidationResult.failure(NAME, ValidationResult.ValidationType.DATA_RULE, "CFTCPart43TransactionReport", path, DEFINITION, failureMessage));
		}
		
		private ComparisonResult executeDataRule(CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			try {
				if (notExists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueSwapIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueSwapIdentifier())).getOrDefault(false)) {
					return exists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueTransactionIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueTransactionIdentifier()));
				}
				return notExists(MapperS.of(cFTCPart43TransactionReport).<String>map("getUniqueTransactionIdentifier", _cFTCPart43TransactionReport -> _cFTCPart43TransactionReport.getUniqueTransactionIdentifier()));
			}
			catch (Exception ex) {
				return ComparisonResult.failure(ex.getMessage());
			}
		}
	}
	
	@SuppressWarnings("unused")
	class NoOp implements CFTCPart43TransactionReportUniqueTransactionIdentifierCondition {
	
		@Override
		public List<ValidationResult<?>> getValidationResults(RosettaPath path, CFTCPart43TransactionReport cFTCPart43TransactionReport) {
			return Collections.emptyList();
		}
	}
}
